==> mediawiki_1.15.5.orig.tar.gz: mediawiki-1.15.5/languages/messages/MessagesCbk_zam.php <==
<?php
/** Chavacano de Zamboanga (Chavacano de Zamboanga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Weekeejames
 */

$fallback = "es";

$messages = array(
# Dates
'january'      => 'Enero',
'february'     => 'Febrero',
'march'        => 'Marzo',
'april'        => 'Abril',
'may_long'     => 'Mayo',
'june'         => 'Junio',
'july'         => 'Julio',
'august'       => 'Agosto',
'september'    => 'Septiembre',
'october'      => 'Octubre',
'november'     => 'Noviembre',
'december'     => 'Diciembre',
'april-gen'    => 'Abril',
'august-gen'   => 'Agosto',
'december-gen' => 'Diciembre',
'apr'          => 'Abr',
'aug'          => 'Ago',
'dec'          => 'Dic',

# Categories related messages
'category_header' => 'Maga articulo na categoria "$1"',

'about'   => 'Acerca de',
'article' => 'El laman del pagina',

'tagline'          => 'Estava na {{SITENAME}}',
'help'             => 'Ayuda',
'search'           => 'Busqueda',
'searchbutton'     => 'Busca',
'searcharticle'    => 'Anda',
'history_short'    => 'Historia',
'printableversion' => 'El version que puede imprenta',
'edit'             => 'Revisa',
'delete'           => 'Bora',
'talkpagelinktext' => 'Cuento',
'personaltools'    => 'Maga herramientas personal',
'articlepage'      => 'Mira con el laman del pagina',
'views'            => 'Maga vista',
'categorypage'     => 'Mira con el pagina de categoria',
'otherlanguages'   => 'na otro maga lenguaje',
'lastmodifiedat'   => 'Ya modifica con este pagina por ultimo vez en hora $2 del $1.', # $1 date, $2 time

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Acerca de {{SITENAME}}',
'aboutpage'            => 'Project:Acerca de',
'copyright'            => 'Obtenible el maga texto de este Wikipedia bajo los terminos y maga condicion del <i>$1</i>.',
'copyrightpage'        => '{{ns:project}}:Maga derecho del autor',
'currentevents'        => 'Maga sucesos actual',
'currentevents-url'    => 'Project:Maga sucesos actual',
'disclaimers'          => 'Maga aviso legal',
'disclaimerpage'       => 'Project:El maga limitacion general de maga responsabilidad',
'mainpage'             => 'El Primero Pagina',
'mainpage-description' => 'El Primero Pagina',
'portal'               => 'Portal del Comunidad',
'privacy'              => 'Policia na proteccion del maga informacion',
'privacypage'          => 'Project:Policia na proteccion del maga informacion',

'retrievedfrom'   => 'Obtenido de "$1"',
'editsectionhint' => 'Revisa el seccion: $1',
'site-rss-feed'   => '$1 Informacion de RSS',
'site-atom-feed'  => '$1 Informacion de Atom',
'red-link-title'  => '$1 (jendeh ta existi el pagina)',

# Login and logout pages
'acct_creation_throttle_hit' => 'Ya crea ya {{PLURAL:$1|un cuenta registro|$1 maga cuenta registro}} el maga visita de este wiki usando el de uste direccion de IP  en el ultimo dia. Entonces, ya sobra ya na maximo numero que ta puede permiti el sistema para crea cuenta. Por causa de este razon, no puede mas crea nuevo cuenta usando el de uste direccion de IP este maga tiempo.',
'accountcreated'             => 'El cuenta registro del usuario es creando',
'accountcreatedtext'         => 'Creao ya el cuenta registro por usuario $1.',

# Edit pages
'blockedtitle' => 'El usuario es prohibido o bloqueado',
'accmailtitle' => 'Enviao ya el contraseña.',
'accmailtext'  => "El contraseña que el sistema ya escogi automatico por usuario [[User talk:$1|$1]] enviado ya a $2.

El contraseña de este nuevo cuenta puede cambia na pagina ''[[Special:ChangePassword|cambia el contraseña]]'' despues el autenticacion.",

# Search results
'search-result-size'        => '$1 ({{PLURAL:$2|1 palabra|$2 maga palabra}})',
'search-mwsuggest-enabled'  => 'con sugestiones',
'search-mwsuggest-disabled' => 'sin sugestion',

# Preferences page
'changepassword' => 'Cambia con el contraseña',

# Recent changes
'recentchanges' => 'Maga Reciente Cambio',

# Random page
'randompage' => 'Pagina Escujido Automatico',

# Special:AllPages
'allarticles' => 'Todo maga articulo',

# Special:Categories
'categories' => 'Maga categoria',

# Watchlist
'watch' => 'Vicia',

'changed' => 'cambiao',
'created' => 'creao',

# Delete
'actioncomplete' => 'Completo el accion',

# Contributions
'contributions' => 'Maga contribuciones del usuario',

# Block/unblock
'blockip'           => 'Usuario prohibido',
'blockipsuccesssub' => 'El prohibicion es confirmado con exito',
'contribslink'      => 'Maga contribuciones',

# Move page
'1movedto2'       => 'Ya move con el articulo de nombre [[$1]] y ahora cambiado ya na nombre [[$2]]',
'1movedto2_redir' => 'Ya move con el articulo de nombre [[$1]] sobre un redireccion y ahora cambiado ya na nombre [[$2]]',

# Tooltip help for the actions
'tooltip-search'     => 'Busca na {{SITENAME}}',
'tooltip-n-mainpage' => 'Visita na Primero Pagina',

);

==> mediawiki_1.19.2.orig.tar.gz: mediawiki-1.19.2/languages/messages/MessagesCbk_zam.php <==
<?php
/** Chavacano de Zamboanga (Chavacano de Zamboanga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Weekeejames
 */

$fallback = "es";

$messages = array(
# Dates
'january'      => 'Enero',
'february'     => 'Febrero',
'march'        => 'Marzo',
'april'        => 'Abril',
'may_long'     => 'Mayo',
'june'         => 'Junio',
'july'         => 'Julio',
'august'       => 'Agosto',
'september'    => 'Septiembre',
'october'      => 'Octubre',
'november'     => 'Noviembre',
'december'     => 'Diciembre',
'april-gen'    => 'Abril',
'august-gen'   => 'Agosto',
'december-gen' => 'Diciembre',
'apr'          => 'Abr',
'aug'          => 'Ago',
'dec'          => 'Dic',

# Categories related messages
'category_header' => 'Maga articulo na categoria "$1"',

'about'   => 'Acerca de',
'article' => 'El laman del pagina',

'tagline'          => 'Estava na {{SITENAME}}',
'help'             => 'Ayuda',
'search'           => 'Busqueda',
'searchbutton'     => 'Busca',
'searcharticle'    => 'Anda',
'history_short'    => 'Historia',
'printableversion' => 'El version que puede imprenta',
'edit'             => 'Revisa',
'delete'           => 'Bora',
'talkpagelinktext' => 'Cuento',
'personaltools'    => 'Maga herramientas personal',
'articlepage'      => 'Mira con el laman del pagina',
'views'            => 'Maga vista',
'categorypage'     => 'Mira con el pagina de categoria',
'otherlanguages'   => 'na otro maga lenguaje',
'lastmodifiedat'   => 'Ya modifica con este pagina por ultimo vez en hora $2 del $1.',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Acerca de {{SITENAME}}',
'aboutpage'            => 'Project:Acerca de',
'copyright'            => 'Obtenible el maga texto de este Wikipedia bajo los terminos y maga condicion del <i>$1</i>.',
'copyrightpage'        => '{{ns:project}}:Maga derecho del autor',
'currentevents'        => 'Maga sucesos actual',
'currentevents-url'    => 'Project:Maga sucesos actual',
'disclaimers'          => 'Maga aviso legal',
'disclaimerpage'       => 'Project:El maga limitacion general de maga responsabilidad',
'mainpage'             => 'El Primero Pagina',
'mainpage-description' => 'El Primero Pagina',
'portal'               => 'Portal del Comunidad',
'privacy'              => 'Policia na proteccion del maga informacion',
'privacypage'          => 'Project:Policia na proteccion del maga informacion',

'retrievedfrom'   => 'Obtenido de "$1"',
'editsectionhint' => 'Revisa el seccion: $1',
'site-rss-feed'   => '$1 Informacion de RSS',
'site-atom-feed'  => '$1 Informacion de Atom',
'red-link-title'  => '$1 (jendeh ta existi el pagina)',

# Login and logout pages
'acct_creation_throttle_hit' => 'Ya crea ya {{PLURAL:$1|un cuenta registro|$1 maga cuenta registro}} el maga visita de este wiki usando el de uste direccion de IP  en el ultimo dia. Entonces, ya sobra ya na maximo numero que ta puede permiti el sistema para crea cuenta. Por causa de este razon, no puede mas crea nuevo cuenta usando el de uste direccion de IP este maga tiempo.',
'accountcreated'             => 'El cuenta registro del usuario es creando',
'accountcreatedtext'         => 'Creao ya el cuenta registro por usuario $1.',

# Edit pages
'blockedtitle' => 'El usuario es prohibido o bloqueado',
'accmailtitle' => 'Enviao ya el contraseña.',
'accmailtext'  => "El contraseña que el sistema ya escogi automatico por usuario [[User talk:$1|$1]] enviado ya a $2.

El contraseña de este nuevo cuenta puede cambia na pagina ''[[Special:ChangePassword|cambia el contraseña]]'' despues el autenticacion.",

# Search results
'search-result-size'        => '$1 ({{PLURAL:$2|1 palabra|$2 maga palabra}})',
'search-mwsuggest-enabled'  => 'con sugestiones',
'search-mwsuggest-disabled' => 'sin sugestion',

# Preferences page
'changepassword' => 'Cambia con el contraseña',

# Recent changes
'recentchanges' => 'Maga Reciente Cambio',

# Random page
'randompage' => 'Pagina Escujido Automatico',

# Special:AllPages
'allarticles' => 'Todo maga articulo',

# Special:Categories
'categories'         => 'Maga categoria',
'categoriespagetext' => 'El maga siguiente {{PLURAL:$1|categoria tiene|categoria tiene}} maga pagina o medio de comunicacion.

El maga [[Special:UnusedCategories|categoria sin usando]] jendeh ta abuya aqui.

Por favor mira tambien el maga [[Special:WantedCategories|categoria requeridas]].',

# Watchlist
'watch' => 'Vicia',

'changed' => 'cambiao',
'created' => 'creao',

# Delete
'actioncomplete' => 'Completo el accion',

# Contributions
'contributions' => 'Maga contribuciones del usuario',

# Block/unblock
'blockip'           => 'Usuario prohibido',
'blockipsuccesssub' => 'El prohibicion es confirmado con exito',
'contribslink'      => 'Maga contribuciones',

# Tooltip help for the actions
'tooltip-search'     => 'Busca na {{SITENAME}}',
'tooltip-n-mainpage' => 'Visita na Primero Pagina',

);
